@@ -1,7 +1,9 @@
-__version__ = "0.1.6"
+__version__ = "0.1.8"
 
 import logging
 from logging.handlers import RotatingFileHandler
+from typing import Optional
+from pathlib import Path
 from logutils.consts import (
     lila,
     lime_green,
@@ -61,7 +63,7 @@ def get_logger(
     level=logging.INFO,
     propagate=False,
     colored=True,
-    filepath=None,
+    filepath: Optional[Path] = None,
 ):
     logger = logging.getLogger(name)
     logger.setLevel(logging.DEBUG)
@@ -72,11 +74,14 @@ def get_logger(
         handler.setFormatter(CustomFormatter(colored=colored))
         handlers.append(handler)
     if "file" in handler_list and filepath is not None:
+        if not filepath.exists():
+            filepath.touch()
         handler = RotatingFileHandler(
             filepath, maxBytes=(1 * 100 * 1024 * 1024), backupCount=10
         )
         handler.setLevel(level)
         handler.setFormatter(CustomFormatter(colored=False))
+        handlers.append(handler)
     if level not in (
         logging.DEBUG,
         logging.INFO,
